@@ -2,7 +2,7 @@
 from pathlib import Path
 
 from outflow.core.logging import logger
-from outflow.core.pipeline import config
+from outflow.core.pipeline import config, context
 from sqlalchemy import create_engine
 from sqlalchemy.exc import NoSuchTableError
 from sqlalchemy.ext.declarative import DeferredReflection
@@ -15,6 +15,10 @@ def get_database_labels():
 
 def connect(func):
     def wrapper(self, *args, **kwargs):
+        if context._models is None:
+            raise Exception(
+                "Databases method/properties can only be called after models have been successfully loaded"
+            )
         if not self.is_connected:
             self.init_all_dbs()
         return func(self, *args, **kwargs)
@@ -32,24 +36,28 @@ class Databases:
 
     def close(self):
         """Close database connections and clear Model metadata"""
-        from outflow.core.pipeline import context
 
         # clear model metadata and reset the context
         for model in context._models:
             model.unregister()
-        context._models = []
+        context._models = None
 
         self._databases.clear()
-        self._session = None
-        self._admin_session = None
+
+        if self._session is not None:
+            self._session.close()
+            self._session = None
+
+        if self._admin_session is not None:
+            self._admin_session.close()
+            self._admin_session = None
+
         self.is_connected = False
 
     def init_all_dbs(self):
         if self.is_connected:
             return
 
-        from outflow.core.pipeline import config
-
         for db_label, login_info in config["databases"].items():
             db = Database(login_info, db_label=db_label)
             self._databases[db_label] = db
@@ -65,7 +73,6 @@ class Databases:
                     for table in database.get_tables()
                 }
             )
-
         return binds
 
     @property
@@ -131,19 +138,21 @@ class Database:
 
         self._reflect()
 
-    def get_tables(self):
+    def get_tables(self, plugin=None):
         """Returns a list of all tables relevant for a bind."""
         result = []
         from outflow.core.db import Model
 
         for table in Model.metadata.tables.values():
             bind_key = table.info.get("bind_key")
+            table_plugin = table.info.get("plugin")
             if (
                 bind_key == self.db_label
                 or bind_key is None
                 and self.db_label == "default"
             ):
-                result.append(table)
+                if plugin is None or plugin is not None and plugin == table_plugin:
+                    result.append(table)
         return result
 
     @property
