@@ -7,7 +7,9 @@ from pathlib import Path
 
 
 def print_exception(logger):
-    def _inner(message=None, log_level="error", use_traceback=True):
+    def _inner(
+        message=None, log_level="error", use_traceback=True
+    ):  # TODO add parameter to print or not in the console
         """
         To handle the printing of the exception message when one occurred. Particularly
         useful when catching errors and want to add debug information on the same
