@@ -277,7 +277,7 @@ class BaseTask(metaclass=TaskMeta):
         if context.db_untracked:
             return
 
-        logger.debug(f"adding edge {child_task} >> {parent_task.name}")
+        logger.debug(f"adding edge {parent_task} >> {child_task}")
         parent_task.db_task.downstream_tasks.append(child_task.db_task)
         context.session.commit()
 
