@@ -3,6 +3,11 @@ from typing import Any, Dict, NewType, Union
 
 from typing_extensions import TypedDict
 
+
+class Skipped:
+    pass
+
+
 TargetOutputs = NewType("TargetOutputs", Union[Dict, None])
 
 
@@ -16,9 +21,9 @@ def outputs_type_factory(type_dict=None, name="TypedTargetOutputs", *args, **kwa
     else:
         output_type = TypedDict(name, type_dict)
         if len(type_dict) == 1:
-            return Union[output_type, next(iter(type_dict.values()))]
+            return Union[output_type, next(iter(type_dict.values())), Skipped]
         else:
-            return output_type
+            return Union[output_type, Skipped]
 
 
 _outflow_map_iterator_prefix = "_OutflowMapIterator__"
