@@ -8,15 +8,17 @@ from pathlib import Path
 import outflow.core.db.alembic as outflow_alembic
 from alembic import command
 from alembic.config import Config, main
+from alembic.script import ScriptDirectory
+from alembic.util.exc import CommandError
 from outflow.core.commands import Command, argument
 from outflow.core.logging import logger
+from outflow.core.pipeline import config, context, settings
 from outflow.core.plugin import Plugin
 from outflow.core.tasks import Task
 from sqlalchemy import UniqueConstraint
-from alembic.util.exc import CommandError
-from .management import Management
-from outflow.core.pipeline import settings, context, config
+
 from ...core.db import Model
+from .management import Management
 
 
 def generate_alembic_ini_file(alembic_ini_path, alembic_config):
@@ -160,6 +162,7 @@ def alembic():
         alembic_args = [
             "-c",
             alembic_ini_path.as_posix(),
+            context.args.command,
             *context.extra_args,
         ]
 
@@ -284,16 +287,16 @@ def MakeMigrations():
     Plugin.load(plugin)
 
     alembic_config_dict = get_alembic_config(db_label, plugin=plugin)
-    cfg = Config()
+    alembic_config = Config()
 
     for key, value in alembic_config_dict["main_options"].items():
-        cfg.set_main_option(key, value)
+        alembic_config.set_main_option(key, value)
 
     for key, value in alembic_config_dict["attributes"].items():
-        cfg.attributes[key] = value
+        alembic_config.attributes[key] = value
 
     for key, value in alembic_config_dict["post_write_hooks"].items():
-        cfg.set_section_option("post_write_hooks", key, value)
+        alembic_config.set_section_option("post_write_hooks", key, value)
 
     logger.info("Calling alembic revision")
 
@@ -324,11 +327,24 @@ def MakeMigrations():
         except IndexError:
             logger.error(f"Unknown argument: {arg}, skipping!")
 
+    script = ScriptDirectory.from_config(alembic_config)
+    heads = script.get_revisions(script.get_heads())
+
+    branch_labels = [
+        label for labels in [head.branch_labels for head in heads] for label in labels
+    ]
+
+    if plugin in branch_labels:
+        branch_label_kw = {"head": f"{plugin}@head", "branch_label": None}
+    else:
+        branch_label_kw = {"head": "base", "branch_label": plugin}
+
     try:
         command.revision(
-            cfg,
+            alembic_config,
             autogenerate=True,
             version_path=plugin_version_path.as_posix(),
+            **branch_label_kw,
             **args,
         )
     except CommandError as ce:
